.. :changelog:

History
-------

0.1.3 (2020-10-12)
++++++++++++++++++

* Fix bug in migrate
* Add traduction FR in package

0.1.2 (2020-10-07)
++++++++++++++++++

* Fix test for use

0.1.1 (2020-10-06)
++++++++++++++++++

* Add organisation & Organisation closure
* Restruct package for better comprehension
* Add tests

0.1.0 (2020-10-06)
++++++++++++++++++

* First release on PyPI.
